@@ -104,7 +104,6 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
-        self._load_optimizer_redis()
   
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
@@ -166,11 +165,45 @@ class KubeModel(ABC):
 
         weight_key = f'{job_id}:optimizer:{func_id}' 
 
-        if  self._redis_client.get(weight_key):
+        if  self._redis_client.exists(weight_key):
             pickled_val = self._redis_client.get(weight_key)
             opt_states = pickle.loads(pickled_val)  
             self.optimizer.load_state_dict(opt_states)
 
+
+    def _save_redis_test(self):
+        """
+        Saves the optimizer to the redis
+        """
+        job_id = self.args._job_id
+        func_id = self.args._func_id
+        epoch = self.args.epoch
+
+        self.logger.debug("Saving optimizer to the database")
+
+        weight_key = f'{job_id}:test:{func_id}' 
+        value = f'{job_id}:optimizer:{func_id}/{epoch}' 
+        self._redis_client.set(weight_key, value)
+
+        self.logger.debug('Saved optimizer to the database')
+
+    def _load_redis_test(self):
+        """
+        Checks for a previously saved state of the optimizer and loads it from redis
+        """
+
+        job_id = self.args._job_id
+        func_id = self.args._func_id
+
+        self.logger.debug("Load optimizer from the database")
+
+        weight_key = f'{job_id}:test:{func_id}' 
+
+        if  self._redis_client.exists(weight_key):
+            pickled_val = self._redis_client.get(weight_key)
+            self.logger.debug("loading value: ", pickled_val)
+
+
     def _get_logger(self):
         """
         Sets the current logger within the network according to the flask context
@@ -253,6 +286,8 @@ class KubeModel(ABC):
         """
         self.__load_model()
         self._load_optimizer_redis()
+        self._load_redis_test()
+
         #self._reset_optimizer_state()
 
     def _on_iteration_end(self):
@@ -262,6 +297,7 @@ class KubeModel(ABC):
         """
         self.__save_model()
         self._save_optimizer_redis()
+        self._save_redis_test()
 
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
